<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>Επισκευή Εκκίνησης του MX </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>Η Επισκευή Boot του MX είναι ένα εργαλείο που μπορεί να χρησιμοποιηθεί για την επανεγκατάσταση του GRUB2 στο ESP (EFI System Partition),  MBR (Master Boot Record) ή root PBR. Παρέχει τη δυνατότητα να ανακατασκευάσει το αρχείο ρυθμίσεων του GRUB2 και να δημιουργήσετε αντίγραφα ασφαλείας και να αποκαταστήσει MBR ή PBR.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Τι θέλατε να κάνετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Αντίγραφο ασφαλείας MBR ή PBR (κληρονομιά εκκίνησης μόνο)  </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Επανεγκατάσταση του εκκινητή φόρτωσης GRUB στο ESP, MBR η PBR (root)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Επισκευή αρχείο ρυθμίσεων του GRUB </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Επαναφορά MBR ή PBR από αντίγραφο ασφαλείας (κληρονομιά εκκίνησης μόνο) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Select Boot Method</source>
        <translation>Επιλεξτε Μέθοδο Εγκατάστασης </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="481"/>
        <source>Install on:</source>
        <translation>Να γίνει εγκατάσταση στο:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>Location:</source>
        <translation>Τοποθεσία: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>Select root location:</source>
        <translation>Επιλέξτε την τοποθεσία root:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>Διαμέρισμα συστήματος EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Βοήθεια </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt+H </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Ακύρωση τις αλλαγές και μετά κλείστε</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Εφαρμόστε τις αλλαγές </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="71"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>Το GRUB εγκαθίσταται στη συσκευή %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="187"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="415"/>
        <location filename="../mainwindow.cpp" line="521"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="187"/>
        <source>Could not create a temporary folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Δεν μπορούσε να δημιουργήσει το chroot.
Ελέγξτε ξανά την επιλεγμένη τοποθεσία.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Το αρχείο διαμόρφωσης GRUB (grub.cfg) ανοικοδομείται.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="229"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Δημιουργία αντιγράφων ασφαλείας του MBR ή του PBR από τη συσκευή %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Warning</source>
        <translation>Προειδοποίηση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>You are going to write the content of </source>
        <translation>Θα γράψετε το περιεχόμενο της</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source> to </source>
        <translation>σε </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>

Are you sure?</source>
        <translation>

Είστε σίγουρος?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Επαναφορά του MBR/PBR από το αντίγραφο ασφαλείας στη συσκευή %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Δεν ήταν δυνατή η εύρεση του χώρου συστήματος EFI (ESP) σε οποιονδήποτε δίσκο συστήματος. Δημιουργήστε ένα ESP και δοκιμάστε ξανά.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Select %1 location:</source>
        <translation>Επιλέξτε την τοποθεσία %1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Η διαδικασία τελείωσε με επιτυχία. &lt;p&gt;&lt;b&gt;Θέλετε να βγείτε;&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Η διαδικασία τελείωσε με λάθη.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Εισαγάγετε τον κωδικό πρόσβασης για να ξεκλειδώσετε το %1 κρυπτογραφημένο διαμέρισμα:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Λυπούμαστε, δεν ήταν δυνατό να ανοίξει το εμπορευματοκιβώτιο %1 LUKS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Select GRUB location</source>
        <translation>Επιλέξτε την τοποθεσία GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Select Item to Back Up</source>
        <translation>Επιλέξτε στοιχείο για δημιουργία αντιγράφων ασφαλείας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Select Item to Restore</source>
        <translation>Επιλέξτε στοιχείο για επαναφορά</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Select backup file name</source>
        <translation>Επιλέξτε το όνομα του αρχείου αντιγράφου ασφαλείας </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>No file was selected.</source>
        <translation>Δεν επελέγη αρχείο. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Επιλέξτε MBR ή PBR αρχείο αντιγράφου ασφαλείας </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>About %1</source>
        <translation>Περί %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>Version: </source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Απλή Επισκευή Εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c)  MX Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>%1 License</source>
        <translation>%1 Άδεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="564"/>
        <source>%1 Help</source>
        <translation>%1 Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Δεν ήταν δυνατή η προσάρτηση %1 </translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Καταγραφή αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Πρέπει να τρέξετε αυτή την εφαρμογή ως Root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Error</source>
        <translation type="unfinished">Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
